@@ -26,23 +26,23 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V11::Enums::ExperimentStatusEnum qw(SETUP);
-use Google::Ads::GoogleAds::V11::Enums::ExperimentTypeEnum qw(SEARCH_CUSTOM);
-use Google::Ads::GoogleAds::V11::Resources::Campaign;
-use Google::Ads::GoogleAds::V11::Resources::Experiment;
-use Google::Ads::GoogleAds::V11::Resources::ExperimentArm;
-use Google::Ads::GoogleAds::V11::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V12::Enums::ExperimentStatusEnum qw(SETUP);
+use Google::Ads::GoogleAds::V12::Enums::ExperimentTypeEnum   qw(SEARCH_CUSTOM);
+use Google::Ads::GoogleAds::V12::Resources::Campaign;
+use Google::Ads::GoogleAds::V12::Resources::Experiment;
+use Google::Ads::GoogleAds::V12::Resources::ExperimentArm;
+use Google::Ads::GoogleAds::V12::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V11::Services::ExperimentService::ExperimentOperation;
+  Google::Ads::GoogleAds::V12::Services::ExperimentService::ExperimentOperation;
 use
-  Google::Ads::GoogleAds::V11::Services::ExperimentArmService::ExperimentArmOperation;
-use Google::Ads::GoogleAds::V11::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V12::Services::ExperimentArmService::ExperimentArmOperation;
+use Google::Ads::GoogleAds::V12::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
-use Cwd qw(abs_path);
+use Cwd          qw(abs_path);
 use Data::Uniqid qw(uniqid);
-use POSIX qw(strftime);
+use POSIX        qw(strftime);
 
 my $customer_id;
 my $campaign_id;
@@ -73,7 +73,7 @@ sub create_experiment {
 sub create_experiment_resource {
   my ($api_client, $customer_id) = @_;
 
-  my $experiment = Google::Ads::GoogleAds::V11::Resources::Experiment->new({
+  my $experiment = Google::Ads::GoogleAds::V12::Resources::Experiment->new({
     # Name must be unique.
     name   => "Example Experiment #" . uniqid(),
     type   => SEARCH_CUSTOM,
@@ -82,7 +82,7 @@ sub create_experiment_resource {
   });
 
   my $operation =
-    Google::Ads::GoogleAds::V11::Services::ExperimentService::ExperimentOperation
+    Google::Ads::GoogleAds::V12::Services::ExperimentService::ExperimentOperation
     ->new({
       create => $experiment
     });
@@ -103,30 +103,30 @@ sub create_experiment_arms {
 
   my $operations = [];
   push @$operations,
-    Google::Ads::GoogleAds::V11::Services::ExperimentArmService::ExperimentArmOperation
+    Google::Ads::GoogleAds::V12::Services::ExperimentArmService::ExperimentArmOperation
     ->new({
-      create => Google::Ads::GoogleAds::V11::Resources::ExperimentArm->new({
+      create => Google::Ads::GoogleAds::V12::Resources::ExperimentArm->new({
           # The "control" arm references an already-existing campaign.
           control   => "true",
           campaigns => [
-            Google::Ads::GoogleAds::V11::Utils::ResourceNames::campaign(
+            Google::Ads::GoogleAds::V12::Utils::ResourceNames::campaign(
               $customer_id, $campaign_id
             )
           ],
-          trial        => $experiment,
+          experiment   => $experiment,
           name         => "control arm",
           trafficSplit => 40
         })});
 
   push @$operations,
-    Google::Ads::GoogleAds::V11::Services::ExperimentArmService::ExperimentArmOperation
+    Google::Ads::GoogleAds::V12::Services::ExperimentArmService::ExperimentArmOperation
     ->new({
-      create => Google::Ads::GoogleAds::V11::Resources::ExperimentArm->new({
+      create => Google::Ads::GoogleAds::V12::Resources::ExperimentArm->new({
           # The non-"control" arm, also called a "treatment" arm, will automatically
           # generate draft campaigns that you can modify before starting the
           # experiment.
           control      => "false",
-          trial        => $experiment,
+          experiment   => $experiment,
           name         => "experiment arm",
           trafficSplit => 60
         })});
@@ -186,12 +186,12 @@ sub modify_draft_campaign {
   # just as you would for any other campaign. When searching with the
   # GoogleAdsService, be sure to include a PARAMETERS clause with
   # `include_drafts = true` when searching for these draft entities.
-  my $updated_campaign = Google::Ads::GoogleAds::V11::Resources::Campaign->new({
+  my $updated_campaign = Google::Ads::GoogleAds::V12::Resources::Campaign->new({
       resourceName => $draft_campaign,
       name => "Modified Campaign Name " . strftime("%Y%m%d", localtime(time))});
 
   my $operation =
-    Google::Ads::GoogleAds::V11::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V12::Services::CampaignService::CampaignOperation->
     new({
       update     => $updated_campaign,
       updateMask => all_set_fields_of($updated_campaign)});
